"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.base_d_source_link_source_parameters import BaseDSourceLinkSourceParameters
from delphix.api.gateway.model.mssqld_source_link_source_parameters_all_of import MSSQLDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.source_operation import SourceOperation
from delphix.api.gateway.model.tag import Tag
globals()['BaseDSourceLinkSourceParameters'] = BaseDSourceLinkSourceParameters
globals()['MSSQLDSourceLinkSourceParametersAllOf'] = MSSQLDSourceLinkSourceParametersAllOf
globals()['SourceOperation'] = SourceOperation
globals()['Tag'] = Tag
from delphix.api.gateway.model.mssqld_source_link_source_parameters import MSSQLDSourceLinkSourceParameters


class TestMSSQLDSourceLinkSourceParameters(unittest.TestCase):
    """MSSQLDSourceLinkSourceParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMSSQLDSourceLinkSourceParameters(self):
        """Test MSSQLDSourceLinkSourceParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MSSQLDSourceLinkSourceParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
